==> mule-parameter-resolver-extension-4.4.0-20221024-sources.jar: org/mule/test/parameter/resolver/extension/extension/NestedWrapperTypesConfig.java <==
/*
 * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
 * The software in this package is published under the terms of the CPAL v1.0
 * license, a copy of which has been included with this distribution in the
 * LICENSE.txt file.
 */
package org.mule.test.parameter.resolver.extension.extension;

import org.mule.runtime.api.metadata.TypedValue;
import org.mule.runtime.extension.api.annotation.Configuration;
import org.mule.runtime.extension.api.annotation.Operations;
import org.mule.runtime.extension.api.annotation.param.Optional;
import org.mule.runtime.extension.api.annotation.param.Parameter;
import org.mule.runtime.extension.api.runtime.parameter.Literal;
import org.mule.runtime.extension.api.runtime.parameter.ParameterResolver;
import org.mule.test.heisenberg.extension.model.KnockeableDoor;

import java.io.InputStream;

@Configuration(name = "nested-types-config")
@Operations(ParameterResolverParameterOperations.class)
public class NestedWrapperTypesConfig extends ParameterResolverExtension {

  @Parameter
  @Optional
  private ParameterResolver<TypedValue<KnockeableDoor>> doorResolver;

  @Parameter
  @Optional
  private ParameterResolver<TypedValue<InputStream>> lazyParameter;

  @Parameter
  @Optional
  private ParameterResolver<ParameterResolver<ParameterResolver<ParameterResolver<TypedValue<InputStream>>>>> nestedParameter;

  @Parameter
  @Optional
  private ParameterResolver<Literal<String>> resolverOfLiteral;

  @Parameter
  @Optional
  private ParameterResolver<TypedValue<String>> lazyString;

  public ParameterResolver<TypedValue<KnockeableDoor>> getDoorResolver() {
    return doorResolver;
  }

  public ParameterResolver<TypedValue<InputStream>> getLazyParameter() {
    return lazyParameter;
  }

  public ParameterResolver<ParameterResolver<ParameterResolver<ParameterResolver<TypedValue<InputStream>>>>> getNestedParameter() {
    return nestedParameter;
  }

  public ParameterResolver<Literal<String>> getResolverOfLiteral() {
    return resolverOfLiteral;
  }

  public ParameterResolver<TypedValue<String>> getLazyString() {
    return lazyString;
  }
}

==> mule-parameter-resolver-extension-4.5.0-rc1-sources.jar: org/mule/test/parameter/resolver/extension/extension/NestedWrapperTypesConfig.java <==
/*
 * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
 * The software in this package is published under the terms of the CPAL v1.0
 * license, a copy of which has been included with this distribution in the
 * LICENSE.txt file.
 */
package org.mule.test.parameter.resolver.extension.extension;

import org.mule.runtime.api.metadata.TypedValue;
import org.mule.runtime.extension.api.annotation.Configuration;
import org.mule.runtime.extension.api.annotation.Operations;
import org.mule.runtime.extension.api.annotation.param.Optional;
import org.mule.runtime.extension.api.annotation.param.Parameter;
import org.mule.runtime.extension.api.runtime.parameter.Literal;
import org.mule.runtime.extension.api.runtime.parameter.ParameterResolver;
import org.mule.test.heisenberg.extension.model.KnockeableDoor;

import java.io.InputStream;

@Configuration(name = "nested-types-config")
@Operations(ParameterResolverParameterOperations.class)
public class NestedWrapperTypesConfig extends ParameterResolverExtension {

  @Parameter
  @Optional
  private ParameterResolver<TypedValue<KnockeableDoor>> doorResolver;

  @Parameter
  @Optional
  private ParameterResolver<TypedValue<InputStream>> lazyParameter;

  @Parameter
  @Optional
  private ParameterResolver<ParameterResolver<org.mule.sdk.api.runtime.parameter.ParameterResolver<ParameterResolver<TypedValue<InputStream>>>>> nestedParameter;

  @Parameter
  @Optional
  private ParameterResolver<org.mule.sdk.api.runtime.parameter.Literal<String>> resolverOfLiteral;

  @Parameter
  @Optional
  private ParameterResolver<TypedValue<String>> lazyString;

  public ParameterResolver<TypedValue<KnockeableDoor>> getDoorResolver() {
    return doorResolver;
  }

  public ParameterResolver<TypedValue<InputStream>> getLazyParameter() {
    return lazyParameter;
  }

  public ParameterResolver<ParameterResolver<org.mule.sdk.api.runtime.parameter.ParameterResolver<ParameterResolver<TypedValue<InputStream>>>>> getNestedParameter() {
    return nestedParameter;
  }

  public ParameterResolver<org.mule.sdk.api.runtime.parameter.Literal<String>> getResolverOfLiteral() {
    return resolverOfLiteral;
  }

  public ParameterResolver<TypedValue<String>> getLazyString() {
    return lazyString;
  }
}
